# pyplottr

[![Build Status](https://travis-ci.org/toaarnio/pyplottr.svg?branch=master)](https://travis-ci.org/toaarnio/pyplottr)

PyPlottr is a convenience wrapper for Matplotlib.

**Installing on Linux:**
```
pip install pyplottr
```

**Documentation:**
```
pydoc pyplottr
```

**Building & installing from source:**
```
make install
```

**Building & releasing to PyPI:**
```
make release
```
